@@ -74,7 +74,7 @@ make.metric <- function(fun, ..., silent = FALSE) {
         ##########
 
         ## If class is matrix -> level3.fun
-        if(class(test)[1] == "matrix") {
+        if(is(test, "matrix")) {
             fun_type <- "level3"
             if(silent != TRUE) {
                 cat(paste(as.expression(match_call$fun)," outputs a matrix object.\n", as.expression(match_call$fun), " is detected as being a dimension-level 3 function.", sep = ""))
@@ -82,7 +82,7 @@ make.metric <- function(fun, ..., silent = FALSE) {
             }
         } else {
             ## If class is numeric
-            if(class(test)[1] == "numeric") {
+            if(is(test, "numeric")) {
                 ## If only one value -> level1.fun
                 if(length(test) == 1) {
                     fun_type <- "level1"
