@@ -189,12 +189,12 @@ SEXP C_char_diff(SEXP x, SEXP smethod, SEXP attrs)
     R_distance(REAL(x), &nr, &nc, REAL(result), &diag, &method);
     
     // Wrap up the results
-    SEXP names = getAttrib(attrs, R_NamesSymbol); // Row/column names attributes
+    SEXP names = PROTECT(getAttrib(attrs, R_NamesSymbol)); // Row/column names attributes
     for (int i = 0; i < LENGTH(attrs); i++) {
         setAttrib(result, install(translateChar(STRING_ELT(names, i))), VECTOR_ELT(attrs, i));
     }
 
-    UNPROTECT(2);
+    UNPROTECT(3);
 
     return result;
 }
